EkycResult class

Constructors

EkycResult({MatchingResult? matchingResult, LivenessResult? livenessResult, bool? faceIsMatch, bool? idFrontIsValid, bool? idBackIsValid, IdFront? idFront, bool? passportIsValid, Passport? passport})
EkycResult.fromJson(Map<String, dynamic> json)
factory

Properties

faceIsMatch bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idBackIsValid bool?
getter/setter pair
idFront IdFront?
getter/setter pair
idFrontIsValid bool?
getter/setter pair
livenessResult LivenessResult?
getter/setter pair
matchingResult MatchingResult?
getter/setter pair
passport Passport?
getter/setter pair
passportIsValid bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({MatchingResult? matchingResult, LivenessResult? livenessResult, bool? faceIsMatch, bool? idFrontIsValid, bool? idBackIsValid, IdFront? idFront, bool? passportIsValid, Passport? passport}) EkycResult
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited